import React, { useMemo} from 'react'
import { Link } from 'react-router-dom'
import {useGoogleAuth} from 'hooks'
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome'
import { faUser } from '@fortawesome/free-solid-svg-icons'
import { Box, Heading, Flex, Spacer, Button, Image, Avatar } from "@chakra-ui/react"
import Logo from '../img/logo.png'

const Nav = () => {
    const { isSignedIn, signOut, signIn, manager } = useGoogleAuth();
    const handleAuth = () => { isSignedIn ? signOut() : signIn();}
    const authLinkText = useMemo(() => isSignedIn ? "Logout" : "Login", [isSignedIn]);
    const userIcon = isSignedIn ? 
    <Avatar name={manager.firstName + " " + manager.lastName} boxSize="40px" borderRadius="full"  src={manager.imageUrl} alt="profile"/> : 
    <FontAwesomeIcon icon={faUser} />

    return (
        <Flex>
            <Box className="left-nav">
                <Link to="/"><Image src={Logo} alt="project logo"/></Link>
            </Box>
            <Spacer />
            <Flex className="right-nav">
                <Link className="nav-link" to="/account">{userIcon}</Link>
                <Button><Link to="/orders">All orders</Link></Button>
                <Button onClick={handleAuth}>{authLinkText}</Button>
            </Flex>
        </Flex>
    )
}

export default Nav
